<?php

namespace Drupal\Tests\datetime_flatpickr\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\datetime_flatpickr\Plugin\Field\FieldWidget\DateTimeFlatPickrWidget;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\FieldDefinitionInterface;

/**
 * Tests the DateTimeFlatPickrWidget massageFormValues() method.
 *
 * @group datetime
 */
class DateTimeFlatPickrWidgetMassageFormValuesTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'system',
    'field',
    'datetime_flatpickr',
  ];

  /**
   * Tests the massageFormValues() method.
   */
  public function testMassageFormValues() {
    // Set the default timezone to UTC.
    date_default_timezone_set('UTC');

    // Create an instance of the DateTimeFlatPickrWidget class.
    $widget = DateTimeFlatPickrWidget::create(
      $this->container,
      [
        'field_definition' => $this->createMock(FieldDefinitionInterface::class),
        'settings' => [],
        'third_party_settings' => [],
      ],
      'datetime_flatpickr',
      ['type' => 'datetime_flatpickr']
    );

    // Create a mock FormStateInterface.
    $formState = $this->createMock(FormStateInterface::class);

    // Set the input values.
    $values = [
      [
        'value' => '2023-05-19 10:50',
      ],
    ];

    $outputValues = $widget->massageFormValues($values, [], $formState);

    $expectedOutputValues = [
      [
        'value' => '2023-05-19T10:50:00',
      ],
    ];
    $this->assertEquals($expectedOutputValues, $outputValues);
  }

}
