<?php

namespace Drupal\Tests\datetime_flatpickr\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\datetime_flatpickr\Plugin\Field\FieldWidget\DateTimeRangeFlatPickrWidget;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\FieldDefinitionInterface;

/**
 * Tests the DateTimeRangeFlatPickrWidget massageFormValues() method.
 *
 * @group datetime_range
 */
class DateTimeRangeFlatPickrWidgetMassageFormValuesTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'system',
    'field',
    'datetime_flatpickr',
  ];

  /**
   * Tests the massageFormValues() method.
   */
  public function testMassageFormValues() {
    // Set the default timezone to UTC.
    date_default_timezone_set('UTC');

    // Create an instance of the DateTimeRangeFlatPickrWidget class.
    $widget = DateTimeRangeFlatPickrWidget::create(
      $this->container,
      [
        'field_definition' => $this->createMock(FieldDefinitionInterface::class),
        'settings' => [],
        'third_party_settings' => [],
      ],
      'datetime_range_flatpickr',
      ['type' => 'datetime_range_flatpickr']
    );

    // Create a mock FormStateInterface.
    $formState = $this->createMock(FormStateInterface::class);

    // Set the input values for start and end date.
    $values = [
      [
        'value' => '2023-05-11 00:00 au 2023-05-27 00:00',
      ],
    ];

    $outputValues = $widget->massageFormValues($values, [], $formState);

    $expectedOutputValues = [
      [
        'value' => '2023-05-11T00:00:00',
        'end_value' => '2023-05-27T00:00:00',
      ],
    ];
    $this->assertEquals($expectedOutputValues, $outputValues);

    // Set the input values for single date only.
    $values = [
      [
        'value' => '2023-05-11 00:00',
      ],
    ];

    $outputValues = $widget->massageFormValues($values, [], $formState);

    $expectedOutputValues = [
      [
        'value' => '2023-05-11T00:00:00',
        'end_value' => '2023-05-11T00:00:00',
      ],
    ];
    $this->assertEquals($expectedOutputValues, $outputValues);
  }

}
